.. _source:


.. raw:: html

     <br><br>

.. title:: Source


**GENOCIDE**

.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.broker		list of bots
    sbn.define		definitions
    sbn.errors		exceptions
    sbn.events          event
    sbn.handle          commands
    sbn.locate          find objects
    sbn.object          clean namespace
    sbn.parser          parse cli
    sbn.reacts          reactor
    sbn.thread          threads
    sbn.timers          repeater


**MODULES**


.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.modules.cmd 	list of commands
    sbn.modules.err     show errors
    sbn.modules.log	log text
    sbn.modules.irc     internet realy chat
    sbn.modules.log     log text
    sbn.modules.req	request
    sbn.modules.rss	rich site syndicate
    sbn.modules.tdo	todo list
    sbn.modules.thr	list threads
